# coding: utf-8
import datetime
import os
from django.conf import settings

from web_edu.plugins.analytic_collector.models import CollectorProvider
from web_edu.plugins.analytic_collector.helpers import CollectPeriod, ProviderContext
from web_edu.plugins.analytic_collector.xmlutils import pretty_xml

from edu_to_analytics.service.utils import (
    PERIOD_TODAY, PERIOD_YESTERDAY, PERIOD_DATE, PERIOD_PERIOD)


periods_map = {
    PERIOD_TODAY: CollectPeriod.CURRENT_DAY,
    PERIOD_YESTERDAY: CollectPeriod.BEFORE_DAY,
    PERIOD_DATE: CollectPeriod.EXACT_DATE,
    PERIOD_PERIOD: CollectPeriod.EXACT_PERIOD
}


def save_result(result, report_code):
    now = datetime.datetime.now().strftime('%m_%d_%Y_%H-%M-%S')
    filename = os.path.join(
        settings.MEDIA_ROOT, settings.UPLOADS, __name__.split('.')[0],
        report_code, '{}.xml'.format(now))
    path = os.path.dirname(filename)
    if not os.path.exists(path):
        os.makedirs(path)
    with open(filename, 'w') as f:
        f.write(result.encode('utf8'))


def get_content(**kwargs):
    u"""Производит сбор показаетля и возвращает его в виде xml"""

    collector_type = periods_map.get(kwargs['period_type'])
    if collector_type == CollectPeriod.EXACT_PERIOD:
        target_dtime = (
            datetime.datetime.combine(kwargs['date_from'], datetime.time.min),
            datetime.datetime.combine(kwargs['date_to'], datetime.time.max)
        )
    elif collector_type == CollectPeriod.EXACT_DATE:
        target_dtime = kwargs['date_from']
    else:
        target_dtime = None

    collector_period = CollectPeriod.get(
        collector_type, target_dtime=target_dtime)
    ctx = ProviderContext(collector_period, collector_type)
    provider = CollectorProvider.objects.get(id=kwargs['report_code'])
    result = pretty_xml(provider.cls().build(ctx))
    save_result(result, kwargs['report_code'])

    return result
